************************************************************************
* This file is part of OpenMolcas.                                     *
*                                                                      *
* OpenMolcas is free software; you can redistribute it and/or modify   *
* it under the terms of the GNU Lesser General Public License, v. 2.1. *
* OpenMolcas is distributed in the hope that it will be useful, but it *
* is provided "as is" and without any express or implied warranties.   *
* For more details see the full text of the license in the file        *
* LICENSE or in <http://www.gnu.org/licenses/>.                        *
************************************************************************
      SubRoutine ChoMP2_SetPtsOen(EOc_,EVir_)
      Implicit None
      Real*8 EOc_(*), EVir_(*)
      Integer ip_of_Work
      External ip_of_Work
#include "chomp2_dec.fh"

      ip_EOc  = ip_of_Work(EOc_(1))
      ip_EVir = ip_of_Work(EVir_(1))

      End
